aboutsummaryrefslogtreecommitdiffstats
path: root/jobs
diff options
context:
space:
mode:
Diffstat (limited to 'jobs')
-rw-r--r--jobs/osmo-gsm-tester-runner.yml6
-rw-r--r--jobs/osmo-gsm-tester_run-gerrit.sh8
-rw-r--r--jobs/osmo-gsm-tester_run-prod.sh8
-rw-r--r--jobs/osmo-gsm-tester_run-rnd.sh8
-rw-r--r--jobs/osmo-gsm-tester_ttcn3.sh6
5 files changed, 18 insertions, 18 deletions
diff --git a/jobs/osmo-gsm-tester-runner.yml b/jobs/osmo-gsm-tester-runner.yml
index d00ecfa..788f057 100644
--- a/jobs/osmo-gsm-tester-runner.yml
+++ b/jobs/osmo-gsm-tester-runner.yml
@@ -225,9 +225,9 @@
- copy_artifact:
repo: osmo-gsm-tester_build-osmocom-bb
- shell: >
- unlink osmo-gsm-tester/example/resources.conf || true
+ unlink osmo-gsm-tester/sysmocom/resources.conf || true
- ln -s resources.conf.virtual osmo-gsm-tester/example/resources.conf
+ ln -s resources.conf.virtual osmo-gsm-tester/sysmocom/resources.conf
# TODO: We (want to) grant CAP_SYS_NICE for osmo-bts-virtual
# but with newer cgroup support and the --cpu-rt-runtime/--ulimit
@@ -236,7 +236,7 @@
docker run --rm=true \
-e HOME=/build \
-e JOB_NAME="$JOB_NAME" \
- -e OSMO_GSM_TESTER_CONF="/build/osmo-gsm-tester/example" \
+ -e OSMO_GSM_TESTER_CONF="/build/osmo-gsm-tester/sysmocom" \
-e OSMO_GSM_TESTER_OPTS="$OSMO_GSM_TESTER_OPTS" \
-e BUILD_NUMBER="$BUILD_NUMBER" \
-w /build -i \
diff --git a/jobs/osmo-gsm-tester_ttcn3.sh b/jobs/osmo-gsm-tester_ttcn3.sh
index a4d5e16..cb973fd 100644
--- a/jobs/osmo-gsm-tester_ttcn3.sh
+++ b/jobs/osmo-gsm-tester_ttcn3.sh
@@ -2,13 +2,13 @@
set -e -x
# On our hardware, we actually use the ttcn3 configuration as-is.
-export OSMO_GSM_TESTER_CONF="$PWD/osmo-gsm-tester/ttcn3"
+export OSMO_GSM_TESTER_CONF="$PWD/osmo-gsm-tester/sysmocom/ttcn3"
# debug: provoke a failure
#export OSMO_GSM_TESTER_OPTS="-s debug -t fail"
-unlink osmo-gsm-tester/ttcn3/resources.conf || true
-ln -s resources.conf.prod osmo-gsm-tester/ttcn3/resources.conf
+unlink osmo-gsm-tester/sysmocom/ttcn3/resources.conf || true
+ln -s resources.conf.prod osmo-gsm-tester/sysmocom/ttcn3/resources.conf
PATH="$PWD/osmo-gsm-tester/src:$PATH" \
./osmo-gsm-tester/ttcn3/jenkins-run.sh
diff --git a/jobs/osmo-gsm-tester_run-gerrit.sh b/jobs/osmo-gsm-tester_run-gerrit.sh
index 4f250be..aa0c5d9 100644
--- a/jobs/osmo-gsm-tester_run-gerrit.sh
+++ b/jobs/osmo-gsm-tester_run-gerrit.sh
@@ -1,14 +1,14 @@
#!/bin/sh
set -e -x
-# On our hardware, we actually use the example configuration as-is.
-export OSMO_GSM_TESTER_CONF="$PWD/osmo-gsm-tester/example"
+# On our hardware, we actually use the sysmocom configuration as-is.
+export OSMO_GSM_TESTER_CONF="$PWD/osmo-gsm-tester/sysmocom"
# debug: provoke a failure
#export OSMO_GSM_TESTER_OPTS="-s debug -t fail"
-unlink osmo-gsm-tester/example/resources.conf || true
-ln -s resources.conf.prod osmo-gsm-tester/example/resources.conf
+unlink osmo-gsm-tester/sysmocom/resources.conf || true
+ln -s resources.conf.prod osmo-gsm-tester/sysmocom/resources.conf
export OSMO_GSM_TESTER_OPTS="-s nitb_sms:sysmo -s sms:sysmo -s gprs:sysmo"
./osmo-gsm-tester/contrib/jenkins-make-check-and-run.sh
diff --git a/jobs/osmo-gsm-tester_run-prod.sh b/jobs/osmo-gsm-tester_run-prod.sh
index bcfe8ed..7614d10 100644
--- a/jobs/osmo-gsm-tester_run-prod.sh
+++ b/jobs/osmo-gsm-tester_run-prod.sh
@@ -1,14 +1,14 @@
#!/bin/sh
set -e -x
-# On our hardware, we actually use the example configuration as-is.
-export OSMO_GSM_TESTER_CONF="$PWD/osmo-gsm-tester/example"
+# On our hardware, we actually use the sysmocom configuration as-is.
+export OSMO_GSM_TESTER_CONF="$PWD/osmo-gsm-tester/sysmocom"
# debug: provoke a failure
#export OSMO_GSM_TESTER_OPTS="-s debug -t fail"
-unlink osmo-gsm-tester/example/resources.conf || true
-ln -s resources.conf.prod osmo-gsm-tester/example/resources.conf
+unlink osmo-gsm-tester/sysmocom/resources.conf || true
+ln -s resources.conf.prod osmo-gsm-tester/sysmocom/resources.conf
PATH="$PWD/osmo-gsm-tester/src:$PATH" \
./osmo-gsm-tester/contrib/jenkins-run.sh
diff --git a/jobs/osmo-gsm-tester_run-rnd.sh b/jobs/osmo-gsm-tester_run-rnd.sh
index 1f8a58a..0bc7fcb 100644
--- a/jobs/osmo-gsm-tester_run-rnd.sh
+++ b/jobs/osmo-gsm-tester_run-rnd.sh
@@ -1,14 +1,14 @@
#!/bin/sh
set -e -x
-# On our hardware, we actually use the example configuration as-is.
-export OSMO_GSM_TESTER_CONF="$PWD/osmo-gsm-tester/example"
+# On our hardware, we actually use the sysmocom configuration as-is.
+export OSMO_GSM_TESTER_CONF="$PWD/osmo-gsm-tester/sysmocom"
# debug: provoke a failure
#export OSMO_GSM_TESTER_OPTS="-s debug -t fail"
-unlink osmo-gsm-tester/example/resources.conf || true
-ln -s resources.conf.rnd osmo-gsm-tester/example/resources.conf
+unlink osmo-gsm-tester/sysmocom/resources.conf || true
+ln -s resources.conf.rnd osmo-gsm-tester/sysmocom/resources.conf
PATH="$PWD/osmo-gsm-tester/src:$PATH" \
./osmo-gsm-tester/contrib/jenkins-run.sh